pub struct App { /* private fields */ }Implementations
Sourceimpl App
impl App
pub fn new(config: Config) -> Result<Self>
Sourcepub fn with_password(config: Config, password: String) -> Result<Self>
pub fn with_password(config: Config, password: String) -> Result<Self>
Create the app with a password-protected secrets vault. Kept for backward compatibility but the TUI now relies on the gateway for vault operations. The password is stored as a deferred vault password to forward after connecting.
Sourcepub fn new_locked(config: Config) -> Result<Self>
pub fn new_locked(config: Config) -> Result<Self>
Create the app with the local vault in a locked state.
Sourcepub fn set_deferred_vault_password(&mut self, password: String)
pub fn set_deferred_vault_password(&mut self, password: String)
Set a vault password to be sent to the gateway after connecting. Used when –password is passed on the command line.
pub async fn run(&mut self) -> Result<()>