Module process_manager

Module process_manager 

Background process session management for RustyClaw.

Provides a registry of background exec sessions that can be polled, written to, and killed by the agent.

Structs

ExecSession
A background exec session.
ProcessManager
Global process session manager.

Enums

SessionStatus
Status of a background session.

Functions

new_shared_manager
Create a new shared process manager.

Type Aliases

SessionId
Unique identifier for a background session.
SharedProcessManager
Thread-safe process manager.