Background process session management for RustyClaw.
Provides a registry of background exec sessions that can be polled, written to, and killed by the agent.
Structs
- Exec
Session - A background exec session.
- Process
Manager - Global process session manager.
Enums
- Session
Status - Status of a background session.
Functions
- new_
shared_ manager - Create a new shared process manager.
Type Aliases
- Session
Id - Unique identifier for a background session.
- Shared
Process Manager - Thread-safe process manager.